@@ -1,7 +1,7 @@
 /*
- *  This file is part of gpw.
+ *  This file is part of gnu-pw-mgr.
  *
- *  Copyright (C) 2013-2014 Bruce Korb, all rights reserved.
+ *  Copyright (C) 2013-2018 Bruce Korb, all rights reserved.
  *  This is free software. It is licensed for use, modification and
  *  redistribution under the terms of the GNU General Public License,
  *  version 3 or later <http://gnu.org/licenses/gpl.html>
@@ -29,34 +29,46 @@
 #ifndef GPW_FWD_GUARD
 #define GPW_FWD_GUARD 1
 #include "gpw-str.h"
-#include "scribble.h"
 #include "set-opt.h"
 
 /*
  * FILE: gnu-pw-mgr.c
  */
+static char *
+load_file(char const * fname);
+
 static void
-adjust_pw(char * buf, size_t bsz, unsigned char * data, size_t d_len);
+set_confirm_value(char * buf, size_t bsz, unsigned char * data, size_t d_len,
+                  char const * pwd_id_str);
+
+static void
+adjust_pw(char * buf, size_t bsz, unsigned char * data, size_t d_len,
+          char const * pwd_id_str);
 
 #if SIZEOF_CHARP > 4
-#else
 #endif
 static void
 get_dft_pw(char * buf, size_t bsz,
-           char const * tag, char const * txt, char const * nam);
+           char const * tag, char const * txt, char const * pwd_id_str);
 
 static void
 get_pbkdf2_pw(char * buf, size_t bsz,
-              char const * tag, char const * txt, char const * nam);
+              char const * tag, char const * salt, char const * pwd_id_str);
 
 static void
-print_pwid_status(char const * name);
+print_pwid_header(char const * pwd_id_str);
+
+static void
+print_pwid_status(char const * pwd_id_str);
 
 static void
 select_chars(unsigned char * txtbuf);
 
+static bool
+print_one_pwid(tOptionValue const * seed_opt, char const * pwd_id_str);
+
 static void
-print_pwid(char const * name);
+print_pwid(char const * pwd_id_str);
 
 static char const *
 assemble_arg(int argc, char ** argv);
@@ -67,6 +79,18 @@ trim(char * in);
 static void
 stdin_pwid(void);
 
+static void
+list_domains(void);
+
+static void
+write_dom_file(void);
+
+static void
+insert_domain(char const * dom);
+
+static void
+proc_dom_opts(int rem_arg_ct);
+
 
 /*
  * FILE: cclass.c
@@ -87,6 +111,7 @@ sanity_check_cclass(void);
 /*
  * FILE: cfg-file.c
  */
+#ifndef SORT_PW_CFG // code for gnu-pw-mgr only
 static char const *
 access_config_file(void);
 
@@ -99,28 +124,48 @@ secure_cfg_file(void);
 static char const *
 load_config_file(void);
 
+#endif // not SORT_PW_CFG only
 static char const *
 find_home(void);
 
+#ifndef SORT_PW_CFG // no --seed-file option for sort
+#endif // SORT_PW_CFG defined
+static char *
+set_cfg_dir(bool * have_local);
+
+#ifndef SORT_PW_CFG
+#endif // ! SORT_PW_CFG
 static char *
 find_cfg_name(void);
 
+#ifndef SORT_PW_CFG
+#endif // ! SORT_PW_CFG
+#ifndef SORT_PW_CFG // code for gnu-pw-mgr only
+static char *
+find_dom_file(void);
+
+#ifndef SORT_PW_CFG
+#endif // ! SORT_PW_CFG
+#endif
 
 /*
  * FILE: fix-pw.c
  */
-static void
-clean_triplets(char * pw);
+static bool
+clean_triplets(char * pw, bool sequence);
 
-static uintptr_t
-ck_pw_classes(char * pw, bool no_spec, char ** first_ch, char ** second_ch);
+static bool
+clean_sequence(char * pw);
 
-static void
-fix_old_pw(char * pw);
+static bool
+clean_no_three(char * pw);
 
 static void
 fix_no_alpha_pw(char * pw);
 
+static void
+fix_lower_only_pw(char * pw);
+
 static uintptr_t
 pick_something(uintptr_t ccls, char * pch, int * cta);
 
@@ -164,6 +209,12 @@ fix_digit_pw(char * pw, uintptr_t * sums);
 static char *
 make_pwid_mark(char const * name, size_t * len);
 
+static char const *
+day_to_string(char const * day_str);
+
+static char const *
+next_pwid_opt(char const * scan, char const * mark, size_t mark_len);
+
 static void
 set_pwid_opts(char const * name);
 
@@ -171,16 +222,48 @@ static void
 remove_opt(char const * txt, char const * mark, size_t m_len,
            set_opt_enum_t typ);
 
+static bool
+removed_old_opts(char const * cfg_text, char const * name, char ** mark_p);
+
 static void
 update_pwid_opts(char const * name);
 
-static char const *
-next_pwid_opt(char const * scan, char const * mark, size_t mark_len);
+static void
+remove_pwid(char const * name);
+
+static void
+insert_load_opts(int * ac, char *** av);
+
+static void
+create_cfg_file(char * opt, char * opt1);
 
 static void
 fix_options(int * ac, char *** av);
 
 
+/*
+ * FILE: scribble.c
+ */
+#ifndef _
+#endif
+#ifndef PVT_static
+#endif
+static void
+scribble_init(void);
+
+static void
+scribble_deinit(void);
+
+static void
+scribble_free(void);
+
+static void *
+scribble_get(ssize_t size);
+
+static void *
+xscribble_get(ssize_t sz);
+
+
 /*
  * FILE: seed.c
  */
@@ -190,9 +273,12 @@ randomize_seed(int wiggle);
 static char const *
 get_seed_text(void);
 
-static void
+static uint32_t
 ver_str_to_number(void);
 
+static inline void
+print_new_seed(FILE * fp, char const * cfg_text);
+
 static void
 add_seed(void);
 
